!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!! Subroutine for "BI-LINEAR INTERPOLATION"                           !
!!! This Subroutine is useful for fine-gridding a coarse-grid 2-D data !
!!! Last Updated: DBS (December 01, 2019)                              !
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!! Inputs to the Subroutine:					       !
!!! 	a1(m1,n1)	: X-variable				       !
!!! 	b1(m1,n1)	: Y-variable				       !
!!! 	c1(m1,n1)	: Z-variable				       !
!!! 	m1		: No. of grid-points along X-axis	       !
!!! 	n1		: No. of grid-points along Y-axis	       !
!!! 	m2		: No. of new grid-points along X-axis 	       !
!!! 	n2		: No. of new grid-points along Y-axis          !
!!! Outputs of the Subroutine:					       !
!!! 	a2(m2,n2)	: X-variable				       !
!!! 	b2(m2,n2)	: Y-variable				       !
!!! 	c2(m2,n2)	: Z-variable				       !
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

	Subroutine Bilinear_Ipolation (a1,b1,c1,m1,n1,a2,b2,c2,m2,n2)

	Real, Dimension(m1,n1)	:: a1, b1, c1
	Real, Dimension(m2,n2)	:: a2, b2, c2

	Real, Dimension(m1-1,n1-1)	:: dcda1, dcdb1
	Real, Dimension(m2-1,n2-1)	:: dcda2, dcdb2

	Integer	:: m1, n1, m2, n2

	da1 = (a1(m1,1) - a1(1,1))/(m1-1) !!! Pre-Assumed: Uniform X-grids
	db1 = (b1(1,n1) - b1(1,1))/(n1-1) !!! Pre-Assumed: Uniform Y-grids

	da2 = (a1(m1,1) - a1(1,1))/(m2-1)
	db2 = (b1(1,n1) - b1(1,1))/(n2-1)

	Do i1 = 1, m1-1
	Do j1 = 1, n1-1
	deltax = c1(i1+1,j1) - c1(i1,j1)
	deltay = c1(i1,j1+1) - c1(i1,j1)
	dcda1(i1,j1)  = deltax/da1
	dcdb1(i1,j1)  = deltay/db1

	Enddo
	Enddo

	Do i2 = 1, m2
	Do j2 = 1, n2

	i1 = ((i2-1)/da1) + 1
	j1 = ((j2-1)/db1) + 1

	a2(i2,j2) = a1(1,1) + (i2-1)*da2 
	b2(i2,j2) = b1(1,1) + (j2-1)*db2

	deltax1 = a2(i2,j2) - a1(i1,j1)
	deltay1 = b2(i2,j2) - b1(i1,j1)
	c2(i2,j2) = c1(i1,j1) + (deltax1*dcda1(i1,j1)) + (deltay1*dcdb1(i1,j1))

	Enddo
	Enddo

	Print *, c1(1,1), c2(1,1)
	Print *, c1(2,1), c2(6,1)
	Print *, c1(1,3), c2(1,11)
	Print *, c1(4,4), c2(16,16)

	Return

	End
